@@ -152,6 +152,7 @@ def read_config(Config, config_file):
 
                'template'                   : 'Kerr',
                'single-mode'                : None,
+               'teob-modes'                 : [(2,2)],
 
                #==============================#
                # Damped sinusoids parameters. #
@@ -196,6 +197,7 @@ def read_config(Config, config_file):
                'gr-time-prior'              : 1,
                'dist-flat-prior'            : 0,
                'ds-amp-flat-prior'          : 0,
+               'free-time-prior'            : 0,
                'mf-time-prior'              : 0.0
 
     }
@@ -469,30 +471,34 @@ def read_injection_parameters(input_par, Config):
         injection_parameters['chia'] = (injection_parameters['m1']*injection_parameters['chi1'] - injection_parameters['m2']*injection_parameters['chi2'])/(injection_parameters['Mi'])
 
     if (input_par['injection-approximant']=='TEOBResumSPM'):
-        injection_parameters_default = {'t0'          : 0.004,
-                                        'm1'          : 50.0,
-                                        'm2'          : 50.0,
-                                        'chi1'        : 0.0,
-                                        'chi2'        : 0.0,
-                                        'phi22'       : 0.0,
-                                        'phi21'       : 0.0,
-                                        'phi33'       : 0.0,
-                                        'phi32'       : 0.0,
-                                        'phi31'       : 0.0,
-                                        'phi44'       : 0.0,
-                                        'phi43'       : 0.0,
-                                        'phi42'       : 0.0,
-                                        'phi41'       : 0.0,
-                                        'phi55'       : 0.0,
-                                        'cosiota'     : 1.0,
-                                        'logdistance' : 6.0857,
-                                        'phi'         : 0.0
+        injection_parameters_default = {'t0'             : 0.004,
+                                        'm1'             : 50.0,
+                                        'm2'             : 50.0,
+                                        'chi1'           : 0.0,
+                                        'chi2'           : 0.0,
+                                        'phi22'          : 0.0,
+                                        'phi21'          : 0.0,
+                                        'phi33'          : 0.0,
+                                        'phi32'          : 0.0,
+                                        'phi31'          : 0.0,
+                                        'phi44'          : 0.0,
+                                        'phi43'          : 0.0,
+                                        'phi42'          : 0.0,
+                                        'phi41'          : 0.0,
+                                        'phi55'          : 0.0,
+                                        'cosiota'        : 1.0,
+                                        'logdistance'    : 6.0857,
+                                        'phi'            : 0.0,
+                                        'inject-modes'   : [(2,2)],
                                         }
 
         for p in list(injection_parameters_default.keys()):
             try:
-                partype = type(injection_parameters_default[p])
-                injection_parameters[p] = partype(Config.get("Injection",p))
+                if(p=='inject-modes'):
+                   injection_parameters[p] = ast.literal_eval(Config.get("Injection",'inject-modes'))
+                else:
+                   partype = type(injection_parameters_default[p])
+                   injection_parameters[p] = partype(Config.get("Injection",p))
             except(KeyError, configparser.NoOptionError, configparser.NoSectionError):
                 injection_parameters[p] = injection_parameters_default[p]
 
@@ -804,7 +810,7 @@ to be intended as part of the default value.
                # Injection parameters. #
                #=======================#
 
-               injection-approximant      Option to select the waveform approximant to be injected.  Current available options: ['Damped-sinusoids', 'Morlet-Gabor-wavelets', 'Kerr', 'MMRDNS', 'MMRDNP', 'KHS_2012', 'NR', 'LAL-X'where X is any LAL approximant]. If 'NR', requires a PYRING_PREFIX to be set. Default: ''.
+               injection-approximant      Option to select the waveform approximant to be injected.  Current available options: ['Damped-sinusoids', 'Morlet-Gabor-wavelets', 'Kerr', 'MMRDNS', 'MMRDNP', 'KHS_2012', 'TEOBResumSPM', 'NR', 'LAL-X'where X is any LAL approximant]. If 'NR', requires a PYRING_PREFIX to be set. Default: ''.
                inject-n-ds-modes        Number of scalar, vector and tensor damped sinuoids to be injected for 'Damped-sinusoids' template. Default: '{"s": 0, "v": 0, "t": 1}'.
                inject-area-quantization   Flag to inject a Kerr waveform with frequencies set by the area quantization proposal in the data. Default: 0.
                inject-charge              Flag to inject a Kerr-Newman waveform. Default: 0.
@@ -816,8 +822,9 @@ to be intended as part of the default value.
                #======================#
 
                template                   Template to be used in the run. Current available options: ['Damped-sinusoids', 'Kerr', 'MMRDNS', 'MMRDNP', 'KHS_2012', 'TEOBResumSPM']. Default: 'Kerr'.
-               single-mode                Option to use a single mode in multi-modal NR waveforms ('MMRDNS', 'MMRDNP', 'KHS_2012', 'TEOBResumSPM'). Example of expected syntax: [(l,m)]. For MMRDNS it fixes the (l,m,0) mode. Default: None.
-
+               single-mode                Option to use a single mode in multi-modal NR waveforms ['MMRDNS', 'MMRDNP', 'KHS_2012']. Example of expected syntax: [(l,m)]. For MMRDNS it fixes the (l,m,0) mode. Default: None.
+               teob-modes                 Modes to be used in 'TEOBResumSPM' template. Available modes: [(2,2), (2,1), (3,3), (3,2), (3,1), (4,4), (4,3), (4,2), (4,1), (5,5)]. For the accuracy of specific modes, see Chapter 6.2.2 and Appendix C.3 of `https://etd.adm.unipi.it/t/etd-10022022-163345`. Default: [(2,2)] (syntax: [(l,m)]).
+               
                #==============================#
                # Damped sinusoids parameters. #
                #==============================#
@@ -885,16 +892,29 @@ to be intended as part of the default value.
                # For more info see: https://johnveitch.github.io/cpnest #
                #========================================================#
 
+               cpnest-branch                Option to switch between different cpnest branches. Available options: [`master`, `massively-parallel`]. Default: 'master'.
+               
+               #===============================#
+               # Branch-independent parameters #
+               #===============================#
+               
                verbose                      Option to set the output verbosity of the sampler. Available options: FIXME MISSING. Default: 2.
-               poolsize                     Option to set the number of pools in the CPNest algorithm. Default: 128.
-               nthreads                     Option to set the number of parallel threads to be used by CPNest. Default: 1.
                nlive                        Option to set the number of live points (main feature controlling the accuracy of the sampling) to be used by CPNest. Default: 1024.
                maxmcmc                      Option to set the number of maximum Markov Chain Monte Carlo steps at each sample (main feature limiting the autocorrelation legth of the samples) to be used by CPNest. Default: 1024.
+
                seed                         Option to set the random seed to be used by CPNest. Default: 1234.
                resume                       Flag to allow CPNest to resume the run after it was killed. Default: 1.
                periodic_checkpoint_interval Option to checkpoint the sampler every `periodic_checkpoint_interval` seconds.  Default: 900.
                
                
+               #=============================#
+               # Branch-dependent parameters #
+               #=============================#
+               
+               poolsize                     Option to set the number of pools in CPNest [`master` branch]. Default: 128.
+               nthreads                     Option to set the number of parallel threads to be used by CPNest [`master` branch]. Default: 1.
+               nnest                        Option to set the number of MISSING in CPnest [`massively-parallel` branch]. Default: 1.
+               nensemble                    Option to set the number of MISSING in CPnest [`massively-parallel` branch]. Default: 1.
 
        *******************************************************
        * Parameters to be passed to the [Injection] section. *
