@@ -234,35 +234,35 @@ def mmrdnp_injection(**kwargs):
     return wf_model
 
 def TEOBPM_injection(**kwargs):
-    
-    multipoles = [(2,2), (3,3), (4,4), (5,5)]
-    
-    t0      = kwargs['injection-parameters']['t0']
-    m1      = kwargs['injection-parameters']['m1']
-    m2      = kwargs['injection-parameters']['m2']
-    chi1    = kwargs['injection-parameters']['chi1']
-    chi2    = kwargs['injection-parameters']['chi2']
-    r       = np.exp(kwargs['injection-parameters']['logdistance'])
-    cosiota = kwargs['injection-parameters']['cosiota']
-    iota    = np.arccos(cosiota)
-    phi     = kwargs['injection-parameters']['phi']
-    TGR_par = {}
-    phases  = {}
 
-    for multipole in multipoles:
-        (l,m) = multipole
+    t0         = kwargs['injection-parameters']['t0']
+    m1         = kwargs['injection-parameters']['m1']
+    m2         = kwargs['injection-parameters']['m2']
+    chi1       = kwargs['injection-parameters']['chi1']
+    chi2       = kwargs['injection-parameters']['chi2']
+    r          = np.exp(kwargs['injection-parameters']['logdistance'])
+    cosiota    = kwargs['injection-parameters']['cosiota']
+    iota       = np.arccos(cosiota)
+    phi        = kwargs['injection-parameters']['phi']
+    modes      = kwargs['injection-parameters']['inject-modes']
+    TGR_par    = {}
+    phases     = {}
+        
+    for mode in modes:
+        (l,m) = mode
         phases[(l,m)] = kwargs['injection-parameters']['phi{}{}'.format(l,m)]
 
-    wf_model = wf.TEOBPM(t0     ,
-                         m1     ,
-                         m2     ,
-                         chi1   ,
-                         chi2   ,
-                         phases ,
-                         r      ,
-                         iota   ,
-                         phi    ,
-                         TGR_par)
+    wf_model = wf.TEOBPM(t0        ,
+                         m1        ,
+                         m2        ,
+                         chi1      ,
+                         chi2      ,
+                         phases    ,
+                         r         ,
+                         iota      ,
+                         phi       ,
+                         modes     ,
+                         TGR_par   )
 
     return wf_model
 
