@@ -20,7 +20,7 @@ from pyRing.inject_signal import inject_IMR_signal, inject_ringdown_signal
 from pyRing.utils         import print_subsection, review_warning, whiten_TD
 from pyRing.likelihood    import toeplitz_slogdet
 
-try:                                      from gwmodel.powerspectrum import mesa as mem
+try:                                      import memspectrum as mem
 except(ImportError, ModuleNotFoundError): pass
 
 
@@ -201,6 +201,7 @@ def set_random_seed(user_seed, ifo):
             
     return
 
+
 ##########################
 # ACF related functions. #
 ##########################
@@ -360,7 +361,7 @@ def compute_acf_and_whitening_psd(times, strain, starttime, T, srate, triggertim
         np.savetxt(os.path.join(kwargs['output'],'Noise','PSD_Welch_{}_{}_{}_{}_{}.txt'.format(ifo, int(starttime), int(T), noise_chunk_size, srate)), np.column_stack((freqs_welch, psd_welch)))
 
     #Case where the PSD is to be computed following the MaxEnt method.
-    elif (not(kwargs['maxent-psd']=='')): ACF, whitening_PSD = compute_maxent_PSD(times, strain, starttime, T, srate, triggertime, index_trigtime, dt, alpha_window, noise_seglen, signal_seglen, fft_acf, freqs_welch, psd_welch, ifo, kwargs)
+    elif (not(kwargs['maxent-psd']=='')): ACF, whitening_PSD = compute_maxent_PSD(times, strain, starttime, T, srate, triggertime, index_trigtime, dt, alpha_window, window_flag, noise_seglen, signal_seglen, fft_acf, freqs_welch, psd_welch, ifo, kwargs)
 
     #Case where the ACF is computed from the data.
     else:
@@ -762,12 +763,12 @@ def read_data_from_txt_file(fname):
 
     return starttime, T, rawstrain
 
-def read_data_from_gwf_file(fname):
+def read_data_from_gwf_file(fname, ifo, kwargs):
     
     ifo_name, fr_type, starttime, T = ((fname.split('/'))[-1]).strip('.gwf').split('-')
-    channel   = kwargs['channel-{}'.format(ifo)]
-    tseries   = TimeSeries.read(fname, channel)
-    rawstrain = np.array(tseries.data)
+    channel                         = kwargs['channel-{}'.format(ifo)]
+    tseries                         = TimeSeries.read(fname, channel)
+    rawstrain                       = np.array(tseries.data)
 
     return starttime, T, rawstrain
 
@@ -795,6 +796,12 @@ def read_data_from_file(fname, ifo, kwargs):
 
     return starttime, dt, srate_dt, T, rawstrain
 
+
+
+#######################
+# Main data function. #
+#######################
+
 #FIXME: this function is too big and should be split. Also, it should be a class or a subclass of the detector class, not a function
 def load_data(ifo, fname, **kwargs):
 
@@ -952,6 +959,7 @@ class detector:
         self.lal_detector                                                = lal.cached_detector_by_prefix[self.name]
         self.location                                                    = self.lal_detector.location
         self.time, self.time_series, self.acf, self.covariance, self.psd = load_data(self.name, datafile, **kwargs)
+        self.sampling_rate                                               = 1./np.diff(self.time)[0]
         
         # Save the times and data that will be actually used in the likelihood.
         np.savetxt(kwargs['output']+'/Noise/signal_chunk_times_data_{det}.txt'.format(det=ifo_name), np.column_stack((self.time, self.time_series)))
@@ -969,9 +977,9 @@ class detector:
         return state
 
     def __setstate__(self, state):
-        self.__dict__ = state
+        self.__dict__     = state
         self.lal_detector = lal.cached_detector_by_prefix[self.name]
-        self.location = self.lal_detector.location
+        self.location     = self.lal_detector.location
 
 
 
@@ -979,13 +987,15 @@ class detector:
 # {Old/currently unused/work in progress} stuff. #
 ##################################################
 
-def mem_psd(freqs_LAL, dt, data, M_max):
+def mem_psd(data, srate, optimisation_method = "FPE"):
 
-    review_warning()
+    #review_warning()
+    M = mem.MESA()
+    M.solve(data, optimisation_method = optimisation_method, early_stop=False)
 
-    return mem.psd(freqs_LAL, dt, data, M_max)
+    return M.spectrum(1./srate, onesided = True)
 
-def compute_maxent_PSD(times, strain, starttime, T, srate, triggertime, index_trigtime, dt, alpha_window, noise_seglen, signal_seglen, fft_acf, freqs_welch, psd_welch, ifo, kwargs):
+def compute_maxent_PSD(times, strain, starttime, T, srate, triggertime, index_trigtime, dt, alpha_window, window_flag, noise_seglen, signal_seglen, fft_acf, freqs_welch, psd_welch, ifo, kwargs):
 
     # References: https://arxiv.org/abs/2106.09499
     review_warning()
@@ -994,12 +1004,12 @@ def compute_maxent_PSD(times, strain, starttime, T, srate, triggertime, index_tr
     df_default    = np.diff(freqs_default)[0]
     if(kwargs['maxent-psd']=='average'):
         sys.stdout.write('* Computing the one-sided average PSD with the MESA method.\n\n')
-        M_max       = int(2.*noise_seglen/np.log(2.*noise_seglen))
-        psds        = [mem_psd(freqs_default, dt, data, M_max) for data in chunks_iterator(times, strain, noise_seglen, avoid=triggertime, window=window_flag, alpha=alpha_window)]
-
+        psds = []
+        for data in chunks_iterator(times, strain, noise_seglen, avoid=triggertime, window=window_flag, alpha=alpha_window):
+            freqs_maxent, psd = mem_psd(data, srate, optimisation_method = "CAT")
+            psds.append(psd)
         if(  kwargs['noise-averaging-method']=='mean'  ): psd_maxent = np.mean(  np.array(psds), axis=0)
         elif(kwargs['noise-averaging-method']=='median'): psd_maxent = np.median(np.array(psds), axis=0)
-
         ACF = 0.5*np.real(np.fft.irfft(psd_maxent*df_default))*noise_seglen
     else:
         M_max = int(2.*signal_seglen/np.log(2.*signal_seglen))
@@ -1015,7 +1025,7 @@ def compute_maxent_PSD(times, strain, starttime, T, srate, triggertime, index_tr
             sys.stdout.write('* Computing the one-sided PSD with the MESA method on the post-onsource chunk.\n\n')
             if not((signal_seglen%2)==0): data = strain[index_trigtime+signal_seglen//2:index_trigtime+signal_seglen//2+1+signal_seglen]
             else                        : data = strain[index_trigtime+signal_seglen//2:index_trigtime+signal_seglen//2+signal_seglen]
-        psd_maxent = mem_psd(freqs_default, dt, data, M_max)
+        freqs_maxent, psd_maxent = mem_psd(data, srate, optimisation_method = "FPE")
         # We are using the one-sided PSD, thus it is twice the Fourier transform of the autocorrelation function (see eq. 7.15 of Maggiore Vol.1). We take the real part just to convert the complex output of fft to a real numpy float. The imaginary part if already 0 when coming out of the fft.
         ACF = 0.5*np.real(np.fft.irfft(psd_maxent*df_default))*signal_seglen
 
@@ -1023,7 +1033,7 @@ def compute_maxent_PSD(times, strain, starttime, T, srate, triggertime, index_tr
                    acf         = ACF,
                    label       = '$\mathrm{ACF \,\, from \,\, MaxEnt}$',
                    output_path = os.path.join(kwargs['output']+'/Noise','{}_ACF.pdf'.format(ifo)))
-    plots.plot_PSD_compare(freqs1      = freqs_default,
+    plots.plot_PSD_compare(freqs1      = freqs_maxent,
                            psd1        = psd_maxent,
                            label1      = "$\mathrm{PSD \,\, from \,\, MaxEnt}$",
                            freqs2      = freqs_welch,
@@ -1031,10 +1041,10 @@ def compute_maxent_PSD(times, strain, starttime, T, srate, triggertime, index_tr
                            label2      = "$\mathrm{Welch, \,\, frequency \,\, domain}$",
                            output_path = os.path.join(kwargs['output'],'Noise','{}_PSD.pdf'.format(ifo)))
 
-    np.savetxt(os.path.join(kwargs['output'],'Noise','ACF_{}_{}_{}_{}_{}.txt'.format(ifo, int(starttime), int(T), noise_chunk_size, srate)), np.column_stack((dt*np.arange(len(ACF)), ACF)))
-    np.savetxt(os.path.join(kwargs['output'],'Noise','PSD_MaxEnt_{}_{}_{}_{}_{}_{}.txt'.format(kwargs['maxent-psd'], ifo, int(starttime), int(T), noise_chunk_size, srate)), np.column_stack((freqs_default, psd_maxent)))
-    np.savetxt(os.path.join(kwargs['output'],'Noise','PSD_Welch_{}_{}_{}_{}_{}.txt'.format(ifo, int(starttime), int(T), noise_chunk_size, srate)), np.column_stack((freqs_welch, psd_welch)))
-    whitening_PSD = psd_maxent
+    np.savetxt(os.path.join(kwargs['output'],'Noise','ACF_{}_{}_{}_{}_{}.txt'.format(ifo, int(starttime), int(T), noise_seglen, srate)), np.column_stack((dt*np.arange(len(ACF)), ACF)))
+    np.savetxt(os.path.join(kwargs['output'],'Noise','PSD_MaxEnt_{}_{}_{}_{}_{}_{}.txt'.format(kwargs['maxent-psd'], ifo, int(starttime), int(T), noise_seglen, srate)), np.column_stack((freqs_maxent, psd_maxent)))
+    np.savetxt(os.path.join(kwargs['output'],'Noise','PSD_Welch_{}_{}_{}_{}_{}.txt'.format(ifo, int(starttime), int(T), noise_seglen, srate)), np.column_stack((freqs_welch, psd_welch)))
+    whitening_PSD = interp1d(freqs_maxent, psd_maxent, fill_value='extrapolate', bounds_error=False)
 
     return ACF, whitening_PSD
 
