@@ -56,6 +56,8 @@ def init_plotting():
     plt.gca().spines['top'].set_color('none')
     plt.gca().xaxis.set_ticks_position('bottom')
     plt.gca().yaxis.set_ticks_position('left')
+    
+    return
 
 def get_param_override(fixed_params,x,name):
     """
@@ -121,7 +123,8 @@ def plot_contour(samples_stacked, level=[0.9], linest = 'dotted', label= None, c
     if(plot_legend): plt.legend([h_x for h_x in hs], [lg for lg in lgs], loc='upper left')
 
     warnings.filterwarnings('default', category=RuntimeWarning)
-
+    
+    return
 
 def plot_strain(get_waveform, dets, fixed_params, tgps, params = None, whiten_flag = False, whiten_method = 'TD', strain_only = 0, **kwargs):
 
@@ -572,7 +575,6 @@ def global_corner(x, names, output):
 
     return
 
-
 def mode_corner(samples,filename=None,**kwargs):
     
     fig = plt.figure(figsize=(10,10))
@@ -706,6 +708,8 @@ def Kerr_intrinsic_corner(x, **input_par):
                   use_math_text = True,
                   truths        = injected_values,
                   filename      = os.path.join(input_par['output'],'Plots/Parameters/Kerr_intrinsic_corner.png'))
+    
+    return
 
 def Kerr_intrinsic_alpha_corner(x, **input_par):
 
@@ -725,6 +729,8 @@ def Kerr_intrinsic_alpha_corner(x, **input_par):
                 use_math_text = True,
                 truths        = injected_values,
                 filename      = os.path.join(input_par['output'],'Plots/Parameters/Kerr_intrinsic_alpha_corner.png'))
+    
+    return
 
 def Kerr_intrinsic_braneworld_corner(x, **input_par):
     
@@ -744,6 +750,8 @@ def Kerr_intrinsic_braneworld_corner(x, **input_par):
                 use_math_text = True,
                 truths        = injected_values,
                 filename      = os.path.join(input_par['output'],'Plots/Parameters/Kerr_intrinsic_braneworld_corner.png'))
+    
+    return
 
 def MMRDNS_intrinsic_corner(x, **input_par):
 
@@ -770,6 +778,8 @@ def MMRDNS_intrinsic_corner(x, **input_par):
                 use_math_text = True,
                 truths        = injected_values,
                 filename      = os.path.join(input_par['output'],'Plots/Parameters/MMRDNS_intrinsic_corner.png'))
+    
+    return
 
 def MMRDNP_intrinsic_corner(x, **input_par):
 
@@ -794,6 +804,8 @@ def MMRDNP_intrinsic_corner(x, **input_par):
                 use_math_text = True,
                 truths        = injected_values,
                 filename      = os.path.join(input_par['output'],'Plots/Parameters/MMRDNP_intrinsic_corner.png'))
+    
+    return
 
 def MMRDNP_amplitude_parameters_corner(x, **input_par):
 
@@ -844,6 +856,8 @@ def MMRDNP_amplitude_parameters_corner(x, **input_par):
                 use_math_text = True,
                 truths        = injected_values,
                 filename      = os.path.join(input_par['output'],'Plots/Parameters/MMRDNP_amplitude_parameters_corner.png'))
+    
+    return
 
 def MMRDNP_Mf_af_plot(x, **input_par):
 
@@ -876,7 +890,10 @@ def MMRDNP_Mf_af_plot(x, **input_par):
                 truths        = injected_values,
                 filename      = os.path.join(input_par['output'],'Plots/Parameters/MMRDNP_Mf_af_plot.png'))
 
+    return
+
 def orientation_corner(x, Config, **input_par):
+    
     pos             = np.column_stack((np.arccos(x['cosiota']), np.exp(x['logdistance'])))
     if(not(input_par['injection-approximant']=='Damped-sinusoids') and not(input_par['injection-approximant']=='')):
         expected_values_orientation = [np.arccos(input_par['injection-parameters']['cosiota']), np.exp(input_par['injection-parameters']['logdistance'])]
@@ -901,9 +918,12 @@ def orientation_corner(x, Config, **input_par):
                 use_math_text = True,
                 truths        = expected_values_orientation,
                 filename      = os.path.join(input_par['output'],'Plots/Parameters/Orientation_corner.png'))
+    
+    return
 
 #IMPROVEME: generalize this plot for different amplitudes in case of injections
 def amplitudes_corner(x, **input_par):
+    
     params = (np.arccos(x['cosiota']), np.exp(x['logdistance']))
     injected_values = None
     if (input_par['injection-approximant']=='Kerr'):
@@ -929,9 +949,11 @@ def amplitudes_corner(x, **input_par):
                      use_math_text = True,
                      truths        = injected_values,
                      filename      = os.path.join(input_par['output'], 'Plots/Parameters/Amplitudes_corner.png'))
-
+    
+    return
 
 def f_tau_amp_corner(x, **input_par):
+    
     for pol in input_par['n-ds-modes'].keys():
         for i in range(input_par['n-ds-modes'][pol]):
             pos             = np.column_stack((x['logA_{}_{}'.format(pol,i)],x['f_{}_{}'.format(pol,i)],1e3*x['tau_{}_{}'.format(pol,i)]))
@@ -951,10 +973,12 @@ def f_tau_amp_corner(x, **input_par):
                         use_math_text = True,
                         truths        = injected_values,
                         filename      = os.path.join(input_par['output'],'Plots/Parameters/Mode_{}_corner.png'.format(i)))
+    return
 
 def tick_function(X): return ['10', '11','12', '13', '14', '15', '16', '17', '18', '19', '20']
 
 def t_start_plot(t0_ds, Mf, **input_par):
+    
     init_plotting()
     Mf                 = Mf * lal.MTSUN_SI
     new_tick_locations = np.array([i*Mf for i in range(10,21)])
@@ -990,8 +1014,11 @@ def t_start_plot(t0_ds, Mf, **input_par):
     plt.legend()
     plt.savefig(os.path.join(output_dir,'t_start.pdf') ,bbox_inches='tight')
 
+    return
+
 def TEOBPM_intrinsic_corner(x, **input_par):
 
+    init_plotting()
     pos             = np.column_stack( (x['m1'], x['m2'], x['chi1'], x['chi2'], x['t0']) )
     injected_values = None
     if (input_par['injection-approximant']=='NR'):
@@ -999,12 +1026,12 @@ def TEOBPM_intrinsic_corner(x, **input_par):
         m2   = input_par['injection-parameters']['m2']
         chi1 = input_par['injection-parameters']['s1z']
         chi2 = input_par['injection-parameters']['s2z']
-        eta = q/((1+q)*(1+q))
+        eta  = q/((1+q)*(1+q))
         injected_values = [m1,  m2, chi1, chi2, None]
 
     mode_corner(  pos,
                   labels        = [r'$m_1 (M_{\odot})$',
-                                   r'$m_2 (M_{\odot})$'            ,
+                                   r'$m_2 (M_{\odot})$',
                                    r'$\chi_1$'         ,
                                    r'$\chi_2$'         ,
                                    r'$t_{start}$'      ],
@@ -1015,6 +1042,27 @@ def TEOBPM_intrinsic_corner(x, **input_par):
                   truths        = injected_values,
                   filename      = os.path.join(input_par['output'],'Plots/Parameters/TEOBPM_intrinsic_corner.png'))
 
+    return
+
+def TEOBPM_masses_spins_corner(x, **input_par):
+    
+    pos        = np.column_stack( (x['m1'], x['m2'], x['chi1'], x['chi2'] ) )
+    output_dir = os.path.join(input_par['output'], 'Plots')
+
+    mode_corner(  pos,
+                  labels        = [r'$m_1 (M_{\odot})$',
+                                   r'$m_2 (M_{\odot})$',
+                                   r'$\chi_1$'         ,
+                                   r'$\chi_2$'         ],
+                  quantiles     = [0.05, 0.5, 0.95],
+                  show_titles   = True,
+                  title_kwargs  = {"fontsize": 12},
+                  use_math_text = True,
+                  truths        = None,
+                  filename      = os.path.join(input_par['output'],'Plots/Parameters/corner_masses_spins.png'))
+
+    return
+
 def Kerr_Newman_intrinsic_corner(x, **input_par):
 
     pos             = np.column_stack( (x['Mf'], x['af'], x['Q']) )
@@ -1030,6 +1078,8 @@ def Kerr_Newman_intrinsic_corner(x, **input_par):
                   truths        = injected_values,
                   filename      = os.path.join(input_par['output'],'Plots/Parameters/Kerr_Newman_intrinsic_corner.png'))
 
+    return
+
 def Mf_af_plot(samples, Mf_LAL_samples, af_LAL_samples, **input_par):
     init_plotting()
     Mf                  = samples['Mf']
@@ -1055,7 +1105,10 @@ def Mf_af_plot(samples, Mf_LAL_samples, af_LAL_samples, **input_par):
     plt.ylabel(r'$\mathrm{a_f}$')
     plt.savefig(os.path.join(output_dir,'Parameters/Mf_af.pdf') ,bbox_inches='tight')
 
+    return
+
 def omega_tau_eff_plot(x, **kwargs):
+    
     Mf         = x['Mf']
     af         = x['af']
     output_dir = os.path.join(kwargs['output'], 'Plots')
@@ -1166,6 +1219,8 @@ def omega_tau_eff_plot(x, **kwargs):
     else:
         raise Exception("Invalid plotting option in omega-tau effective plot.")
 
+    return
+
 def plot_NR_single_mode(t_geom, hr_geom, hi_geom, **kwargs):
 
     init_plotting()
@@ -1232,6 +1287,8 @@ def plot_NR_single_mode(t_geom, hr_geom, hi_geom, **kwargs):
     f.subplots_adjust(hspace=0)
     plt.savefig(os.path.join(output_dir,'SXS_{0}_N_{1}_l_{2}_m_{3}.pdf'.format(kwargs['injection-parameters']['SXS-ID'], kwargs['injection-parameters']['N'], l, m)), bbox_inches='tight')
 
+    return
+
 def single_time_delay_plots(dt_vec, **input_par):
     for det in input_par['detectors']:
         if(det==input_par['ref-det']):
@@ -1247,6 +1304,8 @@ def single_time_delay_plots(dt_vec, **input_par):
             plt.xlabel(r'$N_{samples}$')
             plt.savefig(os.path.join(input_par['output'],'Plots/Parameters/dt_%s%s_chain.png'%(input_par['ref-det'], det)))
 
+    return
+
 def sky_location_plots(x, Config, **input_par):
 
     dt_vec       = {}
@@ -1347,6 +1406,8 @@ def sky_location_plots(x, Config, **input_par):
     except(ValueError):
         pass
 
+    return
+
 def read_Mf_af_IMR_posterior(Config, **input_par):
 
     # Get GR prediction (IMR + UIB NR fits applied on real data) to plot expected values. Using non-precessing fits since no phi12 angle was released alongside GWTC-1
@@ -1411,6 +1472,7 @@ def read_Mf_af_IMR_posterior(Config, **input_par):
             af_d = None
     if((Mf_d is not None) and (af_d is not None)):
         sys.stdout.write('* To predict the GR spectrum of QNM or final mass and spin, the following parameters will be used:\n\n  Mf: {:.3f}  ({:.3f})\n  af: {:.3f}   ({:.3f})\n\n'.format(Mf, dMf, af, daf))
+
     return Mf_d, af_d
 
 def plot_ACF(time, acf, label, output_path):
@@ -1425,6 +1487,8 @@ def plot_ACF(time, acf, label, output_path):
     plt.savefig(output_path, bbox_inches='tight')
     plt.close('all')
 
+    return
+
 def plot_PSD(freqs, psd, label, output_path):
 
     init_plotting()
@@ -1436,6 +1500,8 @@ def plot_PSD(freqs, psd, label, output_path):
     ax.legend()
     plt.savefig(output_path, bbox_inches='tight')
     plt.close('all')
+    
+    return
 
 def plot_ACF_compare(time1, acf1, label1, time2, acf2, label2, output_path):
 
@@ -1449,6 +1515,8 @@ def plot_ACF_compare(time1, acf1, label1, time2, acf2, label2, output_path):
     ax.legend()
     plt.savefig(output_path, bbox_inches='tight')
     plt.close('all')
+    
+    return
 
 def plot_PSD_compare(freqs1, psd1, label1, freqs2, psd2, label2, output_path):
 
@@ -1462,11 +1530,15 @@ def plot_PSD_compare(freqs1, psd1, label1, freqs2, psd2, label2, output_path):
     ax.legend()
     plt.savefig(output_path, bbox_inches='tight')
     plt.close('all')
+    
+    return
 
 def UNUSED_noise_evidence_density(t0_samples,noise_model):
+    
     logZnoise = []
     time = noise_model.times-noise_model.tevent
     for t0 in t0_samples:
         index = np.abs(t0-time).argmin()
         logZnoise.append(np.sum([- 0.5*np.einsum('i, ij, j',s[index:],Cinv[index:,index:],s[index:]) for s,Cinv in zip(noise_model.data,noise_model.inverse_covariance)]))
+    
     return np.array(logZnoise)
