@@ -11,10 +11,10 @@ from .. import likelihood
 
 
 def test_inner_product():
-    a = numpy.asarray([  # identity
+    a = numpy.asarray((0.5, 0.5, 0.))
+    b = numpy.asarray([  # identity
         (1, 0, 0),
         (0, 1, 0),
         (0, 0, 1),
     ], dtype=float)
-    b = numpy.asarray((0.5, 0.5, 0.))
-    assert likelihood.inner_product(a, b) == .5
+    assert likelihood.residuals_inner_product_direct_inversion(a, b) == .5
