@@ -16,17 +16,17 @@ class TestTEOBPM:
     @pytest.fixture
     def smwaveform(cls):
         return cls.WAVEFORM(
-            0.,  # t0
-            10.,  # m1
-            10.,  # m2
-            0.,  # chi1
-            0.,  # chi2
-            {},  # phases
-            1000,  # distance
-            0.,  # iota
-            0.,  # phi
-            {},  # TGR params
-            single_mode=True,
+            0.,             # t0
+            10.,            # m1
+            10.,            # m2
+            0.,             # chi1
+            0.,             # chi2
+            {},             # phases
+            1000,           # distance
+            0.,             # iota
+            0.,             # phi
+            [(2,2), (3,3)], # modes
+            {},             # TGR params
         )
 
     @pytest.mark.parametrize(("l", "m", "a1"), (
