@@ -349,11 +349,9 @@ if(TEOBPM):
                      'inclination' : 0.3              ,
                      'phi'         : 0.0              }
 
-    merger_phases = {(2,2) : 0.0,
-                     (3,3) : 0.0,
-                     (4,4) : 0.0,
-                     (5,5) : 0.0}
-
+    modes = [(2,2), (3,3)]
+    for mode_key in modes.key(): merger_phases[mode_key] = 0.0
+    
     TGR_parameters = {}
     TEOBPM_model = wf.TEOBPM(TEOBPM_params['t0']         ,
                              TEOBPM_params['m1']         ,
@@ -364,10 +362,8 @@ if(TEOBPM):
                              TEOBPM_params['distance']   ,
                              TEOBPM_params['inclination'],
                              TEOBPM_params['phi']        ,
+                             modes                       ,
                              TGR_parameters              ,
-                             single_l    = 2             ,
-                             single_m    = 2             ,
-                             single_mode = 1             ,
                              geom = 0                    )
 
 
